=== modified file 'bzrlib/export/__init__.py'
--- bzrlib/export/__init__.py	2006-08-29 20:47:02 +0000
+++ bzrlib/export/__init__.py	2006-09-20 23:43:18 +0000
@@ -98,6 +98,8 @@
 def get_root_name(dest):
     """Get just the root name for an export.
 
+    >>> get_root_name('../mytest.tar')
+    'mytest'
     >>> get_root_name('mytar.tar')
     'mytar'
     >>> get_root_name('mytar.tar.bz2')

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-09-18 09:47:56 +0000
+++ bzrlib/tests/__init__.py	2006-09-20 23:43:18 +0000
@@ -49,6 +49,7 @@
 import bzrlib.commands
 import bzrlib.bundle.serializer
 import bzrlib.errors as errors
+import bzrlib.export
 import bzrlib.inventory
 import bzrlib.iterablefile
 import bzrlib.lockdir
@@ -89,6 +90,7 @@
                       bzrlib.bundle.serializer,
                       bzrlib.commands,
                       bzrlib.errors,
+                      bzrlib.export,
                       bzrlib.inventory,
                       bzrlib.iterablefile,
                       bzrlib.lockdir,

=== modified file 'bzrlib/tests/blackbox/test_export.py'
--- bzrlib/tests/blackbox/test_export.py	2006-09-20 23:00:51 +0000
+++ bzrlib/tests/blackbox/test_export.py	2006-09-20 23:43:18 +0000
@@ -111,3 +111,106 @@
         # Make sure the exported directory contains 'a', but does not contain
         # '.bzrignore'.
         self.assertEqual(['a'], files)
+
+    def example_branch(self):
+        tree = self.make_branch_and_tree('branch')
+        f = open('branch/hello', 'wb')
+        try:
+            f.write('foo')
+        finally:
+            f.close()
+        tree.add('hello')
+        tree.commit('setup')
+
+        f = open('branch/goodbye', 'wb')
+        try:
+            f.write('baz')
+        finally:
+            f.close()
+        tree.add('goodbye')
+        tree.commit('setup')
+        return tree
+        
+    def test_basic_directory_export(self):
+        self.example_branch()
+        os.chdir('branch')
+
+        # Directory exports
+        self.run_bzr('export', '../latest')
+        self.assertEqual(['goodbye', 'hello'], sorted(os.listdir('../latest')))
+        self.check_file_contents('../latest/goodbye', 'baz')
+        self.run_bzr('export', '../first', '-r', '1')
+        self.assertEqual(['hello'], sorted(os.listdir('../first')))
+        self.check_file_contents('../first/hello', 'foo')
+
+        # Even with .gz and .bz2 it is still a directory
+        self.run_bzr('export', '../first.gz', '-r', '1')
+        self.check_file_contents('../first.gz/hello', 'foo')
+        self.run_bzr('export', '../first.bz2', '-r', '1')
+        self.check_file_contents('../first.bz2/hello', 'foo')
+
+    def test_basic_tarfile_export(self):
+        self.example_branch()
+        os.chdir('branch')
+
+        self.run_bzr('export', '../first.tar', '-r', '1')
+        self.failUnless(os.path.isfile('../first.tar'))
+        tf = tarfile.open('../first.tar')
+        try:
+            self.assertEqual(['first/hello'], sorted(tf.getnames()))
+            self.assertEqual('foo', tf.extractfile('first/hello').read())
+        finally:
+            tf.close()
+
+        self.run_bzr('export', '../first.tar.gz', '-r', '1')
+        self.failUnless(os.path.isfile('../first.tar.gz'))
+        self.run_bzr('export', '../first.tbz2', '-r', '1')
+        self.failUnless(os.path.isfile('../first.tbz2'))
+        self.run_bzr('export', '../first.tar.bz2', '-r', '1')
+        self.failUnless(os.path.isfile('../first.tar.bz2'))
+        self.run_bzr('export', '../first.tar.tbz2', '-r', '1')
+        self.failUnless(os.path.isfile('../first.tar.tbz2'))
+
+        tf = tarfile.open('../first.tar.tbz2', 'r:bz2')
+        try:
+            self.assertEqual(['first.tar/hello'], sorted(tf.getnames()))
+            self.assertEqual('foo', tf.extractfile('first.tar/hello').read())
+        finally:
+            tf.close()
+        self.run_bzr('export', '../first2.tar', '-r', '1', '--root', 'pizza')
+        tf = tarfile.open('../first2.tar')
+        try:
+            self.assertEqual(['pizza/hello'], sorted(tf.getnames()))
+            self.assertEqual('foo', tf.extractfile('pizza/hello').read())
+        finally:
+            tf.close()
+
+    def test_basic_zipfile_export(self):
+        self.example_branch()
+        os.chdir('branch')
+
+        self.run_bzr('export', '../first.zip', '-r', '1')
+        self.failUnlessExists('../first.zip')
+        zf = zipfile.ZipFile('../first.zip')
+        try:
+            self.assertEqual(['first/hello'], sorted(zf.namelist()))
+            self.assertEqual('foo', zf.read('first/hello'))
+        finally:
+            zf.close()
+
+        self.run_bzr('export', '../first2.zip', '-r', '1', '--root', 'pizza')
+        zf = zipfile.ZipFile('../first2.zip')
+        try:
+            self.assertEqual(['pizza/hello'], sorted(zf.namelist()))
+            self.assertEqual('foo', zf.read('pizza/hello'))
+        finally:
+            zf.close()
+        
+        self.run_bzr('export', '../first-zip', '--format=zip', '-r', '1')
+        zf = zipfile.ZipFile('../first-zip')
+        try:
+            self.assertEqual(['first-zip/hello'], sorted(zf.namelist()))
+            self.assertEqual('foo', zf.read('first-zip/hello'))
+        finally:
+            zf.close()
+

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2006-08-29 20:47:02 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2006-09-20 23:43:18 +0000
@@ -147,59 +147,6 @@
         test.runbzr('add goodbye')
         test.runbzr('commit -m setup goodbye')
 
-    def test_export(self):
-        os.mkdir('branch')
-        os.chdir('branch')
-        self.example_branch()
-        self.runbzr('export ../latest')
-        self.assertEqual(file('../latest/goodbye', 'rt').read(), 'baz')
-        self.runbzr('export ../first -r 1')
-        self.assert_(not os.path.exists('../first/goodbye'))
-        self.assertEqual(file('../first/hello', 'rt').read(), 'foo')
-        self.runbzr('export ../first.gz -r 1')
-        self.assertEqual(file('../first.gz/hello', 'rt').read(), 'foo')
-        self.runbzr('export ../first.bz2 -r 1')
-        self.assertEqual(file('../first.bz2/hello', 'rt').read(), 'foo')
-
-        from tarfile import TarFile
-        self.runbzr('export ../first.tar -r 1')
-        self.assert_(os.path.isfile('../first.tar'))
-        tf = TarFile('../first.tar')
-        self.assert_('first/hello' in tf.getnames(), tf.getnames())
-        self.assertEqual(tf.extractfile('first/hello').read(), 'foo')
-        self.runbzr('export ../first.tar.gz -r 1')
-        self.assert_(os.path.isfile('../first.tar.gz'))
-        self.runbzr('export ../first.tbz2 -r 1')
-        self.assert_(os.path.isfile('../first.tbz2'))
-        self.runbzr('export ../first.tar.bz2 -r 1')
-        self.assert_(os.path.isfile('../first.tar.bz2'))
-        self.runbzr('export ../first.tar.tbz2 -r 1')
-        self.assert_(os.path.isfile('../first.tar.tbz2'))
-
-        from bz2 import BZ2File
-        tf = TarFile('../first.tar.tbz2', 
-                     fileobj=BZ2File('../first.tar.tbz2', 'r'))
-        self.assert_('first.tar/hello' in tf.getnames(), tf.getnames())
-        self.assertEqual(tf.extractfile('first.tar/hello').read(), 'foo')
-        self.runbzr('export ../first2.tar -r 1 --root pizza')
-        tf = TarFile('../first2.tar')
-        self.assert_('pizza/hello' in tf.getnames(), tf.getnames())
-
-        from zipfile import ZipFile
-        self.runbzr('export ../first.zip -r 1')
-        self.failUnlessExists('../first.zip')
-        zf = ZipFile('../first.zip')
-        self.assert_('first/hello' in zf.namelist(), zf.namelist())
-        self.assertEqual(zf.read('first/hello'), 'foo')
-
-        self.runbzr('export ../first2.zip -r 1 --root pizza')
-        zf = ZipFile('../first2.zip')
-        self.assert_('pizza/hello' in zf.namelist(), zf.namelist())
-        
-        self.runbzr('export ../first-zip --format=zip -r 1')
-        zf = ZipFile('../first-zip')
-        self.assert_('first-zip/hello' in zf.namelist(), zf.namelist())
-
     def test_inventory(self):
         bzr = self.runbzr
         def output_equals(value, *args):

